@@ -19,6 +19,7 @@
 package ugm
 
 import (
+	"errors"
 	"fmt"
 	"strings"
 	"sync"
@@ -78,7 +79,7 @@ type LimitConfig struct {
 // IncreaseTrackedResource Increase the resource usage for the given user group and queue path combination.
 // As and when every allocation or asks requests fulfilled on application, corresponding user and group
 // resource usage would be increased against specific application.
-func (m *Manager) IncreaseTrackedResource(queuePath, applicationID string, usage *resources.Resource, user security.UserGroup) bool {
+func (m *Manager) IncreaseTrackedResource(queuePath, applicationID string, usage *resources.Resource, user security.UserGroup) {
 	log.Log(log.SchedUGM).Debug("Increasing resource usage",
 		zap.String("user", user.User),
 		zap.String("queue path", queuePath),
@@ -86,7 +87,7 @@ func (m *Manager) IncreaseTrackedResource(queuePath, applicationID string, usage
 		zap.Stringer("resource", usage))
 	if queuePath == common.Empty || applicationID == common.Empty || usage == nil || user.User == common.Empty {
 		log.Log(log.SchedUGM).Debug("Mandatory parameters are missing to increase the resource usage")
-		return false
+		return
 	}
 	// since we check headroom before an increase this should never result in a creation...
 	// some tests might not go through a scheduling that cycle so leave this
@@ -97,15 +98,37 @@ func (m *Manager) IncreaseTrackedResource(queuePath, applicationID string, usage
 	if !userTracker.hasGroupForApp(applicationID) {
 		m.ensureGroupTrackerForApp(queuePath, applicationID, user)
 	}
-
-	return userTracker.increaseTrackedResource(queuePath, applicationID, usage)
+	userTracker.increaseTrackedResource(queuePath, applicationID, usage)
+	appGroup := userTracker.getGroupForApp(applicationID)
+	log.Log(log.SchedUGM).Debug("Increasing resource usage for user",
+		zap.String("user", user.User),
+		zap.String("queue path", queuePath),
+		zap.String("application", applicationID),
+		zap.String("group", appGroup),
+		zap.Stringer("resource", usage))
+	if appGroup == common.Empty {
+		return
+	}
+	groupTracker := m.GetGroupTracker(appGroup)
+	if groupTracker == nil {
+		log.Log(log.SchedUGM).Error("group tracker should be available in groupTrackers map",
+			zap.String("application", applicationID),
+			zap.String("group", appGroup))
+		return
+	}
+	log.Log(log.SchedUGM).Debug("Increasing resource usage for group",
+		zap.String("group", appGroup),
+		zap.String("queue path", queuePath),
+		zap.String("application", applicationID),
+		zap.Stringer("resource", usage))
+	groupTracker.increaseTrackedResource(queuePath, applicationID, usage, userTracker.userName)
 }
 
 // DecreaseTrackedResource Decrease the resource usage for the given user group and queue path combination.
 // As and when every allocation or asks release happens, corresponding user and group
 // resource usage would be decreased against specific application. When the final asks release happens, removeApp should be set to true and
 // application itself would be removed from the tracker and no more usage would be tracked further for that specific application.
-func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage *resources.Resource, user security.UserGroup, removeApp bool) bool {
+func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage *resources.Resource, user security.UserGroup, removeApp bool) {
 	log.Log(log.SchedUGM).Debug("Decreasing resource usage",
 		zap.String("user", user.User),
 		zap.String("queue path", queuePath),
@@ -114,14 +137,14 @@ func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage
 		zap.Bool("removeApp", removeApp))
 	if queuePath == common.Empty || applicationID == common.Empty || usage == nil || user.User == common.Empty {
 		log.Log(log.SchedUGM).Debug("Mandatory parameters are missing to decrease the resource usage")
-		return false
+		return
 	}
 
 	userTracker := m.GetUserTracker(user.User)
 	if userTracker == nil {
 		log.Log(log.SchedUGM).Error("user tracker must be available in userTrackers map",
 			zap.String("user", user.User))
-		return false
+		return
 	}
 
 	// get the group now as the decrease might remove the app from the user if removeApp is true
@@ -130,28 +153,24 @@ func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage
 		zap.String("user", user.User),
 		zap.String("queue path", queuePath),
 		zap.String("application", applicationID),
-		zap.String("tracked group", appGroup),
+		zap.String("group", appGroup),
 		zap.Stringer("resource", usage),
 		zap.Bool("removeApp", removeApp))
-	removeQT, decreased := userTracker.decreaseTrackedResource(queuePath, applicationID, usage, removeApp)
-	if !decreased {
-		return decreased
-	}
-	if removeQT {
+	if userTracker.decreaseTrackedResource(queuePath, applicationID, usage, removeApp) {
 		log.Log(log.SchedUGM).Info("Removing user from manager",
 			zap.String("user", user.User))
 		delete(m.userTrackers, user.User)
 	}
 	// if the app did not have a group we're done otherwise update the groupTracker
 	if appGroup == common.Empty {
-		return decreased
+		return
 	}
 	groupTracker := m.GetGroupTracker(appGroup)
 	if groupTracker == nil {
 		log.Log(log.SchedUGM).Error("group tracker should be available in groupTrackers map",
-			zap.String("applicationID", applicationID),
-			zap.String("applicationID", appGroup))
-		return decreased
+			zap.String("application", applicationID),
+			zap.String("group", appGroup))
+		return
 	}
 	log.Log(log.SchedUGM).Debug("Decreasing resource usage for group",
 		zap.String("group", appGroup),
@@ -159,11 +178,7 @@ func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage
 		zap.String("application", applicationID),
 		zap.Stringer("resource", usage),
 		zap.Bool("removeApp", removeApp))
-	removeQT, decreased = groupTracker.decreaseTrackedResource(queuePath, applicationID, usage, removeApp)
-	if !decreased {
-		return decreased
-	}
-	if removeQT {
+	if groupTracker.decreaseTrackedResource(queuePath, applicationID, usage, removeApp) {
 		log.Log(log.SchedUGM).Info("Removing group from manager",
 			zap.String("group", appGroup),
 			zap.String("queue path", queuePath),
@@ -171,7 +186,6 @@ func (m *Manager) DecreaseTrackedResource(queuePath, applicationID string, usage
 			zap.Bool("removeApp", removeApp))
 		delete(m.groupTrackers, appGroup)
 	}
-	return true
 }
 
 func (m *Manager) GetUsersResources() []*UserTracker {
@@ -226,7 +240,7 @@ func (m *Manager) ensureGroupTrackerForApp(queuePath, applicationID string, user
 		if groupTracker == nil {
 			log.Log(log.SchedUGM).Info("Group tracker doesn't exists. Creating appGroup tracker",
 				zap.String("queue path", queuePath),
-				zap.String("appGroup", appGroup))
+				zap.String("group", appGroup))
 			groupTracker = newGroupTracker(appGroup, m.events)
 			m.Lock()
 			m.groupTrackers[appGroup] = groupTracker
@@ -234,7 +248,7 @@ func (m *Manager) ensureGroupTrackerForApp(queuePath, applicationID string, user
 		}
 	}
 	log.Log(log.SchedUGM).Info("Group tracker set for user application",
-		zap.String("appGroup", appGroup),
+		zap.String("group", appGroup),
 		zap.String("user", user.User),
 		zap.String("application", applicationID),
 		zap.String("queue path", queuePath))
@@ -325,7 +339,7 @@ func (m *Manager) internalProcessConfig(cur configs.QueueConfig, queuePath strin
 				zap.String("queue path", queuePath),
 				zap.Any("limit max resources", limit.MaxResources),
 				zap.Error(err))
-			return fmt.Errorf("problem in using the max resources settings for queuepath: %s. reason: %w", queuePath, err)
+			return errors.Join(fmt.Errorf("problem in using the max resources settings for queuepath: %s, reason: ", queuePath), err)
 		}
 		limitConfig := &LimitConfig{maxResources: maxResource, maxApplications: limit.MaxApplications}
 		for _, user := range limit.Users {
@@ -646,7 +660,7 @@ func (m *Manager) Headroom(queuePath, applicationID string, user security.UserGr
 		return userHeadroom
 	}
 	groupHeadroom := groupTracker.headroom(hierarchy)
-	return resources.ComponentWiseMinPermissive(userHeadroom, groupHeadroom)
+	return resources.ComponentWiseMin(userHeadroom, groupHeadroom)
 }
 
 // CanRunApp checks the maxApplications for this specific application that runs as the user and group.
