@@ -28,6 +28,8 @@ import (
 	"github.com/apache/yunikorn-core/pkg/webservice/dao"
 )
 
+// The QueueTracker is designed to be lock free and should remain as such.
+// Each QueueTracker object is always only linked to single UserTracker or GroupTracker. The responsibility of managing locks is delegated to those objects.
 type QueueTracker struct {
 	queueName           string
 	queuePath           string
@@ -85,9 +87,14 @@ const (
 	group
 )
 
-func (qt *QueueTracker) increaseTrackedResource(hierarchy []string, applicationID string, trackType trackingType, usage *resources.Resource) bool {
+func (tt trackingType) String() string {
+	return [...]string{"none", "user", "group"}[tt]
+}
+
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
+func (qt *QueueTracker) increaseTrackedResource(hierarchy []string, applicationID string, trackType trackingType, usage *resources.Resource) {
 	log.Log(log.SchedUGM).Debug("Increasing resource usage",
-		zap.Int("tracking type", int(trackType)),
+		zap.Stringer("tracking type", trackType),
 		zap.String("queue path", qt.queuePath),
 		zap.Strings("hierarchy", hierarchy),
 		zap.String("application", applicationID),
@@ -100,17 +107,16 @@ func (qt *QueueTracker) increaseTrackedResource(hierarchy []string, applicationI
 		if qt.childQueueTrackers[childName] == nil {
 			qt.childQueueTrackers[childName] = newQueueTracker(qt.queuePath, childName, trackType)
 		}
-		if !qt.childQueueTrackers[childName].increaseTrackedResource(hierarchy[1:], applicationID, trackType, usage) {
-			return false
-		}
+		qt.childQueueTrackers[childName].increaseTrackedResource(hierarchy[1:], applicationID, trackType, usage)
 	}
 	if qt.resourceUsage == nil {
 		qt.resourceUsage = resources.NewResource()
 	}
 	qt.resourceUsage.AddTo(usage)
+	qt.resourceUsage.Prune() // needed as we might be both adding and removing
 	qt.runningApplications[applicationID] = true
 	log.Log(log.SchedUGM).Debug("Successfully increased resource usage",
-		zap.Int("tracking type", int(trackType)),
+		zap.Stringer("tracking type", trackType),
 		zap.String("queue path", qt.queuePath),
 		zap.String("application", applicationID),
 		zap.Stringer("resource", usage),
@@ -119,10 +125,10 @@ func (qt *QueueTracker) increaseTrackedResource(hierarchy []string, applicationI
 		zap.Bool("use wild card", qt.useWildCard),
 		zap.Stringer("total resource after increasing", qt.resourceUsage),
 		zap.Int("total applications after increasing", len(qt.runningApplications)))
-	return true
 }
 
-func (qt *QueueTracker) decreaseTrackedResource(hierarchy []string, applicationID string, usage *resources.Resource, removeApp bool) (bool, bool) {
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
+func (qt *QueueTracker) decreaseTrackedResource(hierarchy []string, applicationID string, usage *resources.Resource, removeApp bool) bool {
 	log.Log(log.SchedUGM).Debug("Decreasing resource usage",
 		zap.String("queue path", qt.queuePath),
 		zap.Strings("hierarchy", hierarchy),
@@ -136,12 +142,9 @@ func (qt *QueueTracker) decreaseTrackedResource(hierarchy []string, applicationI
 		if qt.childQueueTrackers[childName] == nil {
 			log.Log(log.SchedUGM).Error("Child queueTracker tracker must be available in child queues map",
 				zap.String("child queueTracker name", childName))
-			return false, false
-		}
-		removeQT, decreased := qt.childQueueTrackers[childName].decreaseTrackedResource(hierarchy[1:], applicationID, usage, removeApp)
-		if !decreased {
-			return false, decreased
+			return false
 		}
+		removeQT := qt.childQueueTrackers[childName].decreaseTrackedResource(hierarchy[1:], applicationID, usage, removeApp)
 		if removeQT {
 			log.Log(log.SchedUGM).Debug("Removed queue tracker linkage from its parent",
 				zap.String("queue path ", qt.queuePath),
@@ -151,6 +154,7 @@ func (qt *QueueTracker) decreaseTrackedResource(hierarchy []string, applicationI
 		}
 	}
 	qt.resourceUsage.SubFrom(usage)
+	qt.resourceUsage.Prune()
 	if removeApp {
 		log.Log(log.SchedUGM).Debug("Removed application from running applications",
 			zap.String("application", applicationID),
@@ -171,9 +175,10 @@ func (qt *QueueTracker) decreaseTrackedResource(hierarchy []string, applicationI
 	log.Log(log.SchedUGM).Debug("Remove queue tracker",
 		zap.String("queue path ", qt.queuePath),
 		zap.Bool("remove QT", removeQT))
-	return removeQT, true
+	return removeQT
 }
 
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) setLimit(hierarchy []string, maxResource *resources.Resource, maxApps uint64, useWildCard bool, trackType trackingType, doWildCardCheck bool) {
 	log.Log(log.SchedUGM).Debug("Setting limits",
 		zap.String("queue path", qt.queuePath),
@@ -200,6 +205,8 @@ func (qt *QueueTracker) setLimit(hierarchy []string, maxResource *resources.Reso
 	}
 }
 
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
+// Note: headroom is not read-only, it also traverses the queue hierarchy and creates childQueueTracker if it does not exist.
 func (qt *QueueTracker) headroom(hierarchy []string, trackType trackingType) *resources.Resource {
 	// depth first: all the way to the leaf, create if not exists
 	// more than 1 in the slice means we need to recurse down
@@ -214,16 +221,16 @@ func (qt *QueueTracker) headroom(hierarchy []string, trackType trackingType) *re
 
 	// arrived at the leaf or on the way out: check against current max if set
 	if !resources.IsZero(qt.maxResources) {
-		headroom = qt.maxResources.Clone()
-		headroom.SubOnlyExisting(qt.resourceUsage)
+		headroom = resources.SubOnlyExisting(qt.maxResources, qt.resourceUsage)
 	}
 
 	if headroom == nil {
 		return childHeadroom
 	}
-	return resources.ComponentWiseMinPermissive(headroom, childHeadroom)
+	return resources.ComponentWiseMin(headroom, childHeadroom)
 }
 
+// Note: Lock free call. The RLock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) getResourceUsageDAOInfo(parentQueuePath string) *dao.ResourceUsageDAOInfo {
 	if qt == nil {
 		return &dao.ResourceUsageDAOInfo{}
@@ -250,6 +257,7 @@ func (qt *QueueTracker) getResourceUsageDAOInfo(parentQueuePath string) *dao.Res
 
 // IsQueuePathTrackedCompletely Traverse queue path upto the end queue through its linkage
 // to confirm entire queuePath has been tracked completely or not
+// Note: Lock free call. The RLock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) IsQueuePathTrackedCompletely(hierarchy []string) bool {
 	// depth first: all the way to the leaf, ignore if not exists
 	// more than 1 in the slice means we need to recurse down
@@ -271,6 +279,7 @@ func (qt *QueueTracker) IsQueuePathTrackedCompletely(hierarchy []string) bool {
 // linkage needs to be removed or not based on the running applications.
 // If there are any running applications in end leaf queue, we should remove the linkage between
 // the leaf and its parent queue using UnlinkQT method. Otherwise, we should leave as it is.
+// Note: Lock free call. The RLock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) IsUnlinkRequired(hierarchy []string) bool {
 	// depth first: all the way to the leaf, ignore if not exists
 	// more than 1 in the slice means we need to recurse down
@@ -295,6 +304,7 @@ func (qt *QueueTracker) IsUnlinkRequired(hierarchy []string) bool {
 
 // UnlinkQT Traverse queue path upto the end queue. If end queue has any more child queue trackers,
 // then goes upto each child queue and removes the linkage with its immediate parent
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) UnlinkQT(hierarchy []string) bool {
 	log.Log(log.SchedUGM).Debug("Unlinking current queue tracker from its parent",
 		zap.String("current queue ", qt.queueName),
@@ -332,6 +342,7 @@ func (qt *QueueTracker) UnlinkQT(hierarchy []string) bool {
 // decreaseTrackedResourceUsageDownwards queuePath either could be parent or leaf queue path.
 // If it is parent queue path, then reset resourceUsage and runningApplications for all child queues,
 // If it is leaf queue path, reset resourceUsage and runningApplications for queue trackers in this queue path.
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) decreaseTrackedResourceUsageDownwards(hierarchy []string) map[string]bool {
 	// depth first: all the way to the leaf, ignore if not exists
 	// more than 1 in the slice means we need to recurse down
@@ -359,6 +370,8 @@ func (qt *QueueTracker) decreaseTrackedResourceUsageDownwards(hierarchy []string
 	return removedApplications
 }
 
+// Note: Lock free call. The Lock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
+// Note: canRunApp is not read-only, it also traverses the queue hierarchy and creates a childQueueTracker if it does not exist.
 func (qt *QueueTracker) canRunApp(hierarchy []string, applicationID string, trackType trackingType) bool {
 	// depth first: all the way to the leaf, create if not exists
 	// more than 1 in the slice means we need to recurse down
@@ -393,6 +406,7 @@ func (qt *QueueTracker) canRunApp(hierarchy []string, applicationID string, trac
 // canBeRemoved Start from root and reach all levels of queue hierarchy to confirm whether corresponding queue tracker
 // object can be removed from ugm or not. Based on running applications, resource usage, child queue trackers, max running apps, max resources etc
 // it decides the removal. It returns false the moment it sees any unexpected values for any queue in any levels.
+// Note: Lock free call. The RLock of the linked tracker (UserTracker and GroupTracker) should be held before calling this function.
 func (qt *QueueTracker) canBeRemoved() bool {
 	for _, childQT := range qt.childQueueTrackers {
 		// quick check to avoid further traversal
