@@ -31,7 +31,6 @@ import (
 	"github.com/apache/yunikorn-core/pkg/scheduler/objects"
 	"github.com/apache/yunikorn-core/pkg/scheduler/ugm"
 	"github.com/apache/yunikorn-core/pkg/webservice/dao"
-	"github.com/apache/yunikorn-scheduler-interface/lib/go/common"
 	"github.com/apache/yunikorn-scheduler-interface/lib/go/si"
 )
 
@@ -48,9 +47,9 @@ const (
 	taskGroup       = "tg-1"
 	phID            = "ph-1"
 	phID2           = "ph-2"
-	allocID         = "alloc-1"
-	allocID2        = "alloc-2"
-	allocID3        = "alloc-3"
+	allocKey        = "alloc-1"
+	allocKey2       = "alloc-2"
+	allocKey3       = "alloc-3"
 	maxresources    = "maxresources"
 	maxapplications = "maxapplications"
 )
@@ -392,6 +391,7 @@ func newLimitedPartition(resLimit map[string]string) (*PartitionContext, error)
 						Resources: configs.Resources{
 							Max: resLimit,
 						},
+						MaxApplications: 2,
 						Limits: []configs.Limit{
 							{
 								Limit: "limited queue limit",
@@ -554,45 +554,60 @@ func newApplicationTGTagsWithPhTimeout(appID, partition, queueName string, task
 	return objects.NewApplication(siApp, user, nil, rmID)
 }
 
-func newAllocationAskTG(allocKey, appID, taskGroup string, res *resources.Resource, placeHolder bool) *objects.AllocationAsk {
-	return newAllocationAskAll(allocKey, appID, taskGroup, res, 1, 1, placeHolder)
+func newAllocationAskTG(allocKey, appID, taskGroup string, res *resources.Resource, placeHolder bool) *objects.Allocation {
+	return newAllocationAskAll(allocKey, appID, taskGroup, res, 1, placeHolder)
 }
 
-func newAllocationAsk(allocKey, appID string, res *resources.Resource) *objects.AllocationAsk {
-	return newAllocationAskRepeat(allocKey, appID, res, 1)
+func newAllocationAsk(allocKey, appID string, res *resources.Resource) *objects.Allocation {
+	return newAllocationAskAll(allocKey, appID, "", res, 1, false)
 }
 
-func newAllocationAskRepeat(allocKey, appID string, res *resources.Resource, repeat int32) *objects.AllocationAsk {
-	return newAllocationAskPriority(allocKey, appID, res, repeat, 1)
+func newAllocationAskPriority(allocKey, appID string, res *resources.Resource, prio int32) *objects.Allocation {
+	return newAllocationAskAll(allocKey, appID, "", res, prio, false)
 }
 
-func newAllocationAskPriority(allocKey, appID string, res *resources.Resource, repeat int32, prio int32) *objects.AllocationAsk {
-	return newAllocationAskAll(allocKey, appID, "", res, repeat, prio, false)
-}
-
-func newAllocationAskAll(allocKey, appID, taskGroup string, res *resources.Resource, repeat int32, prio int32, placeHolder bool) *objects.AllocationAsk {
-	return objects.NewAllocationAskFromSI(&si.AllocationAsk{
-		AllocationKey:  allocKey,
-		ApplicationID:  appID,
-		PartitionName:  "test",
-		ResourceAsk:    res.ToProto(),
-		MaxAllocations: repeat,
-		Priority:       prio,
-		TaskGroupName:  taskGroup,
-		Placeholder:    placeHolder,
+func newAllocationAskAll(allocKey, appID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool) *objects.Allocation {
+	return objects.NewAllocationFromSI(&si.Allocation{
+		AllocationKey:    allocKey,
+		ApplicationID:    appID,
+		PartitionName:    "test",
+		ResourcePerAlloc: res.ToProto(),
+		Priority:         prio,
+		TaskGroupName:    taskGroup,
+		Placeholder:      placeHolder,
 	})
 }
 
-func newAllocationAskPreempt(allocKey, appID string, prio int32, res *resources.Resource) *objects.AllocationAsk {
-	return objects.NewAllocationAskFromSI(&si.AllocationAsk{
-		AllocationKey:  allocKey,
-		ApplicationID:  appID,
-		PartitionName:  "default",
-		ResourceAsk:    res.ToProto(),
-		MaxAllocations: 1,
-		Priority:       prio,
-		TaskGroupName:  taskGroup,
-		Placeholder:    false,
+func newAllocationTG(allocKey, appID, nodeID, taskGroup string, res *resources.Resource, placeHolder bool) *objects.Allocation {
+	return newAllocationAll(allocKey, appID, nodeID, taskGroup, res, 1, placeHolder)
+}
+
+func newAllocation(allocKey, appID, nodeID string, res *resources.Resource) *objects.Allocation {
+	return newAllocationAll(allocKey, appID, nodeID, "", res, 1, false)
+}
+
+func newAllocationAll(allocKey, appID, nodeID, taskGroup string, res *resources.Resource, prio int32, placeHolder bool) *objects.Allocation {
+	return objects.NewAllocationFromSI(&si.Allocation{
+		AllocationKey:    allocKey,
+		ApplicationID:    appID,
+		PartitionName:    "test",
+		NodeID:           nodeID,
+		ResourcePerAlloc: res.ToProto(),
+		Priority:         prio,
+		TaskGroupName:    taskGroup,
+		Placeholder:      placeHolder,
+	})
+}
+
+func newAllocationAskPreempt(allocKey, appID string, prio int32, res *resources.Resource) *objects.Allocation {
+	return objects.NewAllocationFromSI(&si.Allocation{
+		AllocationKey:    allocKey,
+		ApplicationID:    appID,
+		PartitionName:    "default",
+		ResourcePerAlloc: res.ToProto(),
+		Priority:         prio,
+		TaskGroupName:    taskGroup,
+		Placeholder:      false,
 		PreemptionPolicy: &si.PreemptionPolicy{
 			AllowPreemptSelf:  true,
 			AllowPreemptOther: true,
@@ -601,10 +616,8 @@ func newAllocationAskPreempt(allocKey, appID string, prio int32, res *resources.
 }
 func newNodeWithResources(nodeID string, max, occupied *resources.Resource) *objects.Node {
 	proto := &si.NodeInfo{
-		NodeID: nodeID,
-		Attributes: map[string]string{
-			common.NodeReadyAttribute: "true",
-		},
+		NodeID:              nodeID,
+		Attributes:          map[string]string{},
 		SchedulableResource: max.ToProto(),
 		OccupiedResource:    occupied.ToProto(),
 	}
@@ -627,9 +640,9 @@ func createQueuesNodes(t *testing.T) *PartitionContext {
 	var res *resources.Resource
 	res, err = resources.NewResourceFromConf(map[string]string{"vcore": "10"})
 	assert.NilError(t, err, "failed to create basic resource")
-	err = partition.AddNode(newNodeMaxResource("node-1", res), nil)
+	err = partition.AddNode(newNodeMaxResource("node-1", res))
 	assert.NilError(t, err, "test node1 add failed unexpected")
-	err = partition.AddNode(newNodeMaxResource("node-2", res), nil)
+	err = partition.AddNode(newNodeMaxResource("node-2", res))
 	assert.NilError(t, err, "test node2 add failed unexpected")
 	return partition
 }
@@ -647,9 +660,9 @@ func createPreemptionQueuesNodes(t *testing.T) *PartitionContext {
 	assert.NilError(t, err, "test partition create failed with error")
 	res, err := resources.NewResourceFromConf(map[string]string{"vcore": "10"})
 	assert.NilError(t, err, "failed to create basic resource")
-	err = partition.AddNode(newNodeMaxResource("node-1", res), nil)
+	err = partition.AddNode(newNodeMaxResource("node-1", res))
 	assert.NilError(t, err, "test node1 add failed unexpected")
-	err = partition.AddNode(newNodeMaxResource("node-2", res), nil)
+	err = partition.AddNode(newNodeMaxResource("node-2", res))
 	assert.NilError(t, err, "test node2 add failed unexpected")
 	return partition
 }
