@@ -47,7 +47,7 @@ var (
 	AsyncDispatchLimit         int32
 	AsyncDispatchCheckInterval = 3 * time.Second
 	DispatchTimeout            time.Duration
-	asyncDispatchCount         int32 = 0
+	asyncDispatchCount         atomic.Int32 = atomic.Int32{}
 )
 
 // central dispatcher that dispatches scheduling events.
@@ -57,6 +57,7 @@ type Dispatcher struct {
 	handlers  map[EventType]map[string]func(interface{})
 	running   atomic.Value
 	lock      locking.RWMutex
+	stopped   sync.WaitGroup
 }
 
 func initDispatcher() {
@@ -168,14 +169,14 @@ func (p *Dispatcher) dispatch(event events.SchedulingEvent) error {
 // async-dispatch try to enqueue the event in every 3 seconds util timeout,
 // it's only called when event channel is full.
 func (p *Dispatcher) asyncDispatch(event events.SchedulingEvent) {
-	count := atomic.AddInt32(&asyncDispatchCount, 1)
+	count := asyncDispatchCount.Add(1)
 	log.Log(log.ShimDispatcher).Warn("event channel is full, transition to async-dispatch mode",
 		zap.Int32("asyncDispatchCount", count))
 	if count > AsyncDispatchLimit {
 		panic(fmt.Errorf("dispatcher exceeds async-dispatch limit"))
 	}
 	go func(beginTime time.Time, stop chan struct{}) {
-		defer atomic.AddInt32(&asyncDispatchCount, -1)
+		defer asyncDispatchCount.Add(-1)
 		for p.isRunning() {
 			select {
 			case <-stop:
@@ -212,6 +213,7 @@ func Start() {
 		return
 	}
 	getDispatcher().stopChan = make(chan struct{})
+	getDispatcher().stopped.Add(1)
 	go func() {
 		for {
 			select {
@@ -230,6 +232,7 @@ func Start() {
 			case <-getDispatcher().stopChan:
 				log.Log(log.ShimDispatcher).Info("shutting down event channel")
 				getDispatcher().setRunning(false)
+				getDispatcher().stopped.Done()
 				return
 			}
 		}
@@ -258,13 +261,22 @@ func Stop() {
 	}
 
 	close(getDispatcher().stopChan)
-	maxTimeout := 5
-	for getDispatcher().isRunning() && maxTimeout > 0 {
-		log.Log(log.ShimDispatcher).Info("waiting for dispatcher to be stopped",
-			zap.Int("remainingSeconds", maxTimeout))
-		time.Sleep(1 * time.Second)
-		maxTimeout--
+	stopWait := make(chan struct{})
+
+	go func() {
+		defer close(stopWait)
+		getDispatcher().stopped.Wait()
+	}()
+
+	// wait until the main event loop stops properly
+	select {
+	case <-stopWait:
+		break
+	case <-time.After(5 * time.Second):
+		log.Log(log.ShimDispatcher).Info("dispatcher did not stop in time")
+		break
 	}
+
 	if getDispatcher().isRunning() {
 		log.Log(log.ShimDispatcher).Warn("dispatcher even processing did not stop properly")
 	} else {
