@@ -69,9 +69,8 @@ func TestPreemptionPredicatesEmpty(t *testing.T) {
 	node := framework.NewNodeInfo()
 	node.SetNode(&v1.Node{})
 	victims := make([]*v1.Pod, 0)
-	index, ok := predicateManager.PreemptionPredicates(pod, node, victims, 0)
-	assert.Check(t, !ok, "check should have failed")
-	assert.Equal(t, index, -1, "wrong index")
+	index := predicateManager.PreemptionPredicates(pod, node, victims, 0)
+	assert.Equal(t, index, -1, "should not find any victim index after preemption check")
 }
 
 func TestPreemptionPredicates(t *testing.T) {
@@ -91,8 +90,8 @@ func TestPreemptionPredicates(t *testing.T) {
 	node.SetNode(&v1.Node{
 		ObjectMeta: metav1.ObjectMeta{Name: "node0", UID: "node0"},
 		Status: v1.NodeStatus{
-			Capacity:    makeResources(1000, 100000000, 10, 0, 0, 0).Capacity,
-			Allocatable: makeAllocatableResources(1000, 100000000, 10, 0, 0, 0),
+			Capacity:    makeResources(1000, 100000000, 10, 0, 0, 0),
+			Allocatable: makeResources(1000, 100000000, 10, 0, 0, 0),
 		},
 	})
 	victims := []*v1.Pod{
@@ -115,18 +114,16 @@ func TestPreemptionPredicates(t *testing.T) {
 	node.AddPod(victims[3])
 
 	// all but 1 existing pod should need removing
-	index, ok := predicateManager.PreemptionPredicates(pod, node, victims, 1)
-	assert.Check(t, ok, "check failed")
-	assert.Equal(t, index, 2, "wrong index")
+	index := predicateManager.PreemptionPredicates(pod, node, victims, 1)
+	assert.Equal(t, index, 2, "wrong victim index")
 
 	// try again, but with too many resources requested
 	pod = newResourcePod(framework.Resource{MilliCPU: 1500, Memory: 15000000})
 	pod.Name = "largepod"
 	pod.UID = "largepod"
 
-	index, ok = predicateManager.PreemptionPredicates(pod, node, victims, 1)
-	assert.Check(t, !ok, "check should have failed")
-	assert.Equal(t, index, -1, "wrong index")
+	index = predicateManager.PreemptionPredicates(pod, node, victims, 1)
+	assert.Equal(t, index, -1, "should not find any victim index after preemption check")
 }
 
 func TestEventsToRegister(t *testing.T) {
@@ -150,7 +147,7 @@ func TestEventsToRegister(t *testing.T) {
 	assert.NilError(t, err)
 	assert.Equal(t, int(fn0), -1, "wrong fn (0)")
 	assert.Equal(t, events[1].Event.Resource, framework.Pod, "wrong resource (1)")
-	assert.Equal(t, events[1].Event.ActionType, framework.All, "wrong action type (1)")
+	assert.Equal(t, events[1].Event.ActionType, framework.Add|framework.Delete|framework.UpdatePodLabel, "wrong action type (1)")
 	fn1, err := events[1].QueueingHintFn(klog.NewKlogr(), nil, "", "")
 	assert.NilError(t, err)
 	assert.Equal(t, int(fn1), -1, "wrong fn (1)")
@@ -224,7 +221,7 @@ func newPod(host string, hostPortInfos ...string) *v1.Pod {
 	for _, portInfo := range hostPortInfos {
 		split := strings.Split(portInfo, "/")
 		//nolint:errcheck
-		hostPort, _ := strconv.Atoi(split[2])
+		hostPort, _ := strconv.ParseInt(split[2], 10, 32)
 
 		networkPorts = append(networkPorts, v1.ContainerPort{
 			HostIP:   split[1],
@@ -360,6 +357,7 @@ func TestPodFitsHostPorts(t *testing.T) {
 	}
 }
 
+//nolint:funlen
 func TestPodFitsSelector(t *testing.T) {
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
@@ -1087,20 +1085,7 @@ func newResourcePod(usage ...framework.Resource) *v1.Pod {
 	}
 }
 
-func makeResources(milliCPU, memory, pods, extendedA, storage, hugePageA int64) v1.NodeResources {
-	return v1.NodeResources{
-		Capacity: v1.ResourceList{
-			v1.ResourceCPU:              *resource.NewMilliQuantity(milliCPU, resource.DecimalSI),
-			v1.ResourceMemory:           *resource.NewQuantity(memory, resource.BinarySI),
-			v1.ResourcePods:             *resource.NewQuantity(pods, resource.DecimalSI),
-			extendedResourceA:           *resource.NewQuantity(extendedA, resource.DecimalSI),
-			v1.ResourceEphemeralStorage: *resource.NewQuantity(storage, resource.BinarySI),
-			hugePageResourceA:           *resource.NewQuantity(hugePageA, resource.BinarySI),
-		},
-	}
-}
-
-func makeAllocatableResources(milliCPU, memory, pods, extendedA, storage, hugePageA int64) v1.ResourceList {
+func makeResources(milliCPU, memory, pods, extendedA, storage, hugePageA int64) v1.ResourceList {
 	return v1.ResourceList{
 		v1.ResourceCPU:              *resource.NewMilliQuantity(milliCPU, resource.DecimalSI),
 		v1.ResourceMemory:           *resource.NewQuantity(memory, resource.BinarySI),
@@ -1149,7 +1134,7 @@ func TestRunGeneralPredicates(t *testing.T) {
 				newResourcePod(framework.Resource{MilliCPU: 9, Memory: 19})),
 			node: &v1.Node{
 				ObjectMeta: metav1.ObjectMeta{Name: "machine1"},
-				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0).Capacity, Allocatable: makeAllocatableResources(10, 20, 32, 0, 0, 0)},
+				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0), Allocatable: makeResources(10, 20, 32, 0, 0, 0)},
 			},
 			fits: true,
 			wErr: nil,
@@ -1161,7 +1146,7 @@ func TestRunGeneralPredicates(t *testing.T) {
 				newResourcePod(framework.Resource{MilliCPU: 5, Memory: 19})),
 			node: &v1.Node{
 				ObjectMeta: metav1.ObjectMeta{Name: "machine1"},
-				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0).Capacity, Allocatable: makeAllocatableResources(10, 20, 32, 0, 0, 0)},
+				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0), Allocatable: makeResources(10, 20, 32, 0, 0, 0)},
 			},
 			fits: false,
 			wErr: nil,
@@ -1176,7 +1161,7 @@ func TestRunGeneralPredicates(t *testing.T) {
 			nodeInfo: framework.NewNodeInfo(),
 			node: &v1.Node{
 				ObjectMeta: metav1.ObjectMeta{Name: "machine1"},
-				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0).Capacity, Allocatable: makeAllocatableResources(10, 20, 32, 0, 0, 0)},
+				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0), Allocatable: makeResources(10, 20, 32, 0, 0, 0)},
 			},
 			fits: false,
 			wErr: nil,
@@ -1187,7 +1172,7 @@ func TestRunGeneralPredicates(t *testing.T) {
 			nodeInfo: framework.NewNodeInfo(newPodWithPort(123)),
 			node: &v1.Node{
 				ObjectMeta: metav1.ObjectMeta{Name: "machine1"},
-				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0).Capacity, Allocatable: makeAllocatableResources(10, 20, 32, 0, 0, 0)},
+				Status:     v1.NodeStatus{Capacity: makeResources(10, 20, 32, 0, 0, 0), Allocatable: makeResources(10, 20, 32, 0, 0, 0)},
 			},
 			fits: false,
 			wErr: nil,
@@ -1205,6 +1190,7 @@ func TestRunGeneralPredicates(t *testing.T) {
 	}
 }
 
+//nolint:funlen
 func TestInterPodAffinity(t *testing.T) {
 	clientSet := clientSet()
 	informerFactory := informerFactory(clientSet)
