@@ -36,6 +36,7 @@ import (
 	"github.com/apache/yunikorn-k8shim/pkg/cache"
 	"github.com/apache/yunikorn-k8shim/pkg/client"
 	"github.com/apache/yunikorn-k8shim/pkg/common"
+	"github.com/apache/yunikorn-k8shim/pkg/common/constants"
 	"github.com/apache/yunikorn-k8shim/pkg/common/events"
 	"github.com/apache/yunikorn-k8shim/pkg/common/utils"
 	"github.com/apache/yunikorn-k8shim/pkg/conf"
@@ -124,7 +125,7 @@ func (fc *MockScheduler) addNode(nodeName string, nodeLabels map[string]string,
 		AddResource(siCommon.CPU, cpu).
 		AddResource("pods", pods).
 		Build()
-	request := common.CreateUpdateRequestForNewNode(nodeName, nodeLabels, nodeResource, nil, nil, true)
+	request := createUpdateRequestForNewNode(nodeName, nodeLabels, nodeResource, nil)
 	fmt.Printf("report new nodes to scheduler, request: %s", request.String())
 	return fc.apiProvider.GetAPIs().SchedulerAPI.UpdateNode(request)
 }
@@ -162,17 +163,12 @@ func (fc *MockScheduler) waitAndAssertApplicationState(t *testing.T, appID, expe
 	}
 }
 
-func (fc *MockScheduler) removeApplication(appId string) error {
-	return fc.context.RemoveApplication(appId)
-}
-
 func (fc *MockScheduler) waitAndAssertTaskState(t *testing.T, appID, taskID, expectedState string) {
 	app := fc.context.GetApplication(appID)
 	assert.Equal(t, app != nil, true)
 	assert.Equal(t, app.GetApplicationID(), appID)
 
-	task, err := app.GetTask(taskID)
-	assert.NilError(t, err, "Task retrieval failed")
+	task := app.GetTask(taskID)
 	deadline := time.Now().Add(10 * time.Second)
 	for {
 		if task.GetTaskState() == expectedState {
@@ -340,3 +336,32 @@ func (fc *MockScheduler) ensureStarted() {
 		panic("mock scheduler is not started - call start() first")
 	}
 }
+func createUpdateRequestForNewNode(nodeID string, nodeLabels map[string]string, capacity *si.Resource, occupied *si.Resource) *si.NodeRequest {
+	// Use node's name as the NodeID, this is because when bind pod to node,
+	// name of node is required but uid is optional.
+	nodeInfo := &si.NodeInfo{
+		NodeID:              nodeID,
+		SchedulableResource: capacity,
+		OccupiedResource:    occupied,
+		Attributes: map[string]string{
+			constants.DefaultNodeAttributeHostNameKey: nodeID,
+			constants.DefaultNodeAttributeRackNameKey: constants.DefaultRackName,
+		},
+		Action: si.NodeInfo_CREATE,
+	}
+
+	// Add nodeLabels key value to Attributes map
+	for k, v := range nodeLabels {
+		nodeInfo.Attributes[k] = v
+	}
+
+	// Add instanceType to Attributes map
+	nodeInfo.Attributes[siCommon.InstanceType] = nodeLabels[conf.GetSchedulerConf().InstanceTypeNodeLabelKey]
+
+	nodes := make([]*si.NodeInfo, 1)
+	nodes[0] = nodeInfo
+	return &si.NodeRequest{
+		Nodes: nodes,
+		RmID:  conf.GetSchedulerConf().ClusterID,
+	}
+}
